leaftools.repeat_leaves_in_expr_and_extend_spanners
===================================================

.. autofunction:: abjad.tools.leaftools.repeat_leaves_in_expr_and_extend_spanners.repeat_leaves_in_expr_and_extend_spanners
